# Kinematic Wavelet Analysis Kit (KWAK)

KWAK is a Python package that generates a statistical analysis based on discrete Haar wavelets. 

### Install   
Run to install 

    pip install kwak   

### References
[1] G. F. Giudice, Y. Kats, M. McCullough, R. Torre and A. Urbano, JHEP 1806, 009 (2018) doi:10.1007/JHEP06(2018)009 [arXiv:1711.08437 [hep-ph]].   
[2] V. Rentala, W. Shepherd and T. M. P. Tait, JHEP 1408, 042 (2014) doi:10.1007/JHEP08(2014)042 [arXiv:1404.1929 [hep-ph]].   
[3] J. W. Monk, [arXiv:1405.5008 [hep-ph]]; P. Hansen, J. W. Monk and C. Wiglesworth, arXiv:1812.07412 [hep-ph].   
[4] see e.g. S. D. McDermott, P. J. Fox, I. Cholis and S. K. Lee, JCAP 1607, no. 07, 045 (2016) doi:10.1088/1475-7516/2016/07/045 [arXiv:1512.00012 [astro-ph.HE]]; B. Bal- aji, I. Cholis, P. J. Fox and S. D. McDermott, Phys. Rev. D 98, no. 4, 043009 (2018) doi:10.1103/PhysRevD.98.043009 [arXiv:1803.01952 [astro-ph.HE]].   
[5] A. Haar, Mathematische Annalen 69, 331 (1910) doi:10.1007/BF01456326   
[6] J. O. Irwin, Journal of the Royal Statistical Society 100, 415 (1937) www.jstor.org/stable/2980526   
[7] for a pedagogical discussion see e.g. C. Neitzel, bachelor thesis, Heidelberg (2017)   
[8] M. Aaboud et al. [ATLAS Collaboration], Phys. Lett. B 775, 105 (2017)   
doi:10.1016/j.physletb.2017.10.039 [arXiv:1707.04147 [hep-ex]].   
[9] R. A. Fisher, “Statistical Methods for Research Workers, v.5", Edinburgh: Oliver and Boyd (1934)   
[10] M. Spalla, master thesis, Pisa (2013)   
